Changelog for adi.trash
=======================
 

0.6 (2018-10-15)
----------------

- Fix bug on deletion from folder-contents (thanks to 'laulaz' for reporting).
[ida]


0.5 (2018-09-27)
----------------

- Set trashed items' workflow-state to 'private' after trashing,
  so trashed content does not get unintentionally exposed. [ida]


- Give temporary Contributor-role to user, for pasting into
  trashcan and creating trashcans. Fix #7. [ida]

- Include CHANGES in long-description of this egg, so it gets
  displayed on pypi. [ida]


0.4 (2018-03-03)
----------------

- 'ParseResult' object has no attribute 'endswith', fix error.  [amariscal]


0.3 (2017-07-27)
----------------

- Regard URL can contain parameters, fixes #3. [idgserpro]

- Add plone.api as a dependency. [idgserpro]


0.2 (2017-04-12)
----------------

- Merge PR from idgserpro, correct repo-URL. [ida]


0.1 (2015-11-01)
---------------

- Initial commit.
    
